@@ -1,32 +1,34 @@
 from .analysis import AnalysisCompiler
-from .body_description import BodyDescriptionCompiler
 from .case import CaseCompiler
-from .analysis_description import AnalysisDescriptionCompiler
+from .description import DescriptionCompiler
 from .extraction import ExtractionCompiler
 from .predicate import PredicateCompiler
 from .request import RequestCompiler
-from .response_description import ResponseDescriptionCompiler
+from .request_body import RequestBodyCompiler
+from .response import ResponseDescriptionCompiler
+from .response_body import ResponseBodyDescriptionCompiler
 from .scenario import ScenarioCompiler
 
 
 def create_compiler() -> ScenarioCompiler:
-    request = RequestCompiler()
+    request_body = RequestBodyCompiler()
+    request = RequestCompiler(body=request_body)
 
     extraction = ExtractionCompiler()
     analysis = AnalysisCompiler()
     predicate = PredicateCompiler()
-    description = AnalysisDescriptionCompiler(
-        extraction_compiler=extraction,
-        predicate_compiler=predicate,
+    description = DescriptionCompiler(
+        extraction=extraction,
+        predicate=predicate,
     )
-    body_description = BodyDescriptionCompiler(
+    response_body_description = ResponseBodyDescriptionCompiler(
         analysis=analysis,
         description=description,
     )
     response = ResponseDescriptionCompiler(
         predicate=predicate,
         description=description,
-        body=body_description,
+        body=response_body_description,
     )
     case = CaseCompiler(
         request=request,
