@@ -4,48 +4,58 @@ from __future__ import annotations
 
 from collections.abc import Mapping
 from dataclasses import dataclass, replace
-from datetime import datetime
 from typing import Optional
 
-from preacher.core.interpretation.value import RelativeDatetimeValue
-from preacher.core.scenario import (
-    Request,
-    Parameter,
-    Parameters,
-    ParameterValue,
-)
+from preacher.core.scenario import Request, Method, UrlParams
 from .error import CompilationError, on_key
-from .util import compile_str, compile_mapping, map_compile, or_else
+from .request_body import RequestBodyCompiled, RequestBodyCompiler
+from .url_param import compile_url_params
+from .util import compile_str, compile_mapping, or_else
 
+_KEY_METHOD = 'method'
 _KEY_PATH = 'path'
 _KEY_HEADERS = 'headers'
 _KEY_PARAMS = 'params'
+_KEY_BODY = 'body'
+
+_METHOD_MAP = {method.name: method for method in Method}
 
 
 @dataclass(frozen=True)
 class RequestCompiled:
+    method: Optional[Method] = None
     path: Optional[str] = None
     headers: Optional[Mapping] = None
-    params: Optional[Parameters] = None
+    params: Optional[UrlParams] = None
+    body: Optional[RequestBodyCompiled] = None
 
     def replace(self, other: RequestCompiled) -> RequestCompiled:
         return RequestCompiled(
+            method=or_else(other.method, self.method),
             path=or_else(other.path, self.path),
             headers=or_else(other.headers, self.headers),
             params=other.params if other.params is not None else self.params,
+            body=or_else(other.body, self.body),
         )
 
     def fix(self) -> Request:
         return Request(
+            method=or_else(self.method, Method.GET),
             path=or_else(self.path, ''),
             headers=self.headers,
             params=self.params,
+            body=self.body.fix() if self.body else None
         )
 
 
 class RequestCompiler:
 
-    def __init__(self, default: RequestCompiled = None):
+    def __init__(
+        self,
+        body: RequestBodyCompiler,
+        default: RequestCompiled = None,
+    ):
+        self._body = body
         self._default = default or RequestCompiled()
 
     def compile(self, obj) -> RequestCompiled:
@@ -57,6 +67,12 @@ class RequestCompiler:
         obj = compile_mapping(obj)
         compiled = self._default
 
+        method_obj = obj.get(_KEY_METHOD)
+        if method_obj is not None:
+            with on_key(_KEY_METHOD):
+                method = _compile_method(method_obj)
+            compiled = replace(compiled, method=method)
+
         path_obj = obj.get(_KEY_PATH)
         if path_obj is not None:
             with on_key(_KEY_PATH):
@@ -72,61 +88,33 @@ class RequestCompiler:
         params_obj = obj.get(_KEY_PARAMS)
         if params_obj is not None:
             with on_key(_KEY_PARAMS):
-                params = _compile_params(params_obj)
+                params = compile_url_params(params_obj)
             compiled = replace(compiled, params=params)
 
+        body_obj = obj.get(_KEY_BODY)
+        if body_obj is not None:
+            with on_key(_KEY_BODY):
+                body = self._body.compile(body_obj)
+            compiled = replace(compiled, body=body)
+
         return compiled
 
     def of_default(self, default: RequestCompiled) -> RequestCompiler:
-        return RequestCompiler(default=self._default.replace(default))
+        body = self._body
+        if default.body:
+            body = body.of_default(default.body)
 
-
-def compile_param_value(value: object) -> ParameterValue:
-    if value is None:
-        return value
-    if isinstance(value, bool):
-        return value
-    if isinstance(value, int):
-        return value
-    if isinstance(value, float):
-        return value
-    if isinstance(value, str):
-        return value
-    if isinstance(value, datetime):
-        return value
-    if isinstance(value, RelativeDatetimeValue):  # HACK: relax typing.
-        return value
-    raise CompilationError(
-        f'Not allowed type for a request parameter value: {value.__class__}'
-    )
-
-
-def _compile_param(value: object) -> Parameter:
-    if value is None:
-        return value
-    if isinstance(value, list):
-        return list(map_compile(compile_param_value, value))
-    try:
-        return compile_param_value(value)
-    except CompilationError as error:
-        raise CompilationError(
-            f'Not allowed type for a request parameter: {value.__class__}',
-            cause=error
+        return RequestCompiler(
+            body=body,
+            default=self._default.replace(default)
         )
 
 
-def _compile_params(params: object) -> Parameters:
-    if isinstance(params, str):
-        return params
-
-    if not isinstance(params, Mapping):
-        raise CompilationError('Must be a string or a map')
-    compiled = {}
-    for key, value in params.items():
-        if not isinstance(key, str):
-            raise CompilationError(
-                f'A parameter key must be a string, given {key}'
-            )
-        with on_key(key):
-            compiled[key] = _compile_param(value)
-    return compiled
+def _compile_method(obj: object) -> Method:
+    key = compile_str(obj).upper()
+    method = _METHOD_MAP.get(key)
+    if not method:
+        raise CompilationError(
+            message=f'Must be in {list(_METHOD_MAP)}, but given: {obj}',
+        )
+    return method
