@@ -2,8 +2,7 @@ from concurrent.futures import ThreadPoolExecutor
 from typing import Iterable, Optional
 
 from .listener import Listener
-from .scenario import Scenario
-from .scenario.status import Status
+from .scenario import Scenario, Status
 
 
 class ScenarioRunner:
