@@ -1,7 +1,6 @@
 from .analysis import Analyzer, Analysis, analyze_json_str, analyze_xml_str
-from .analysis_description import AnalysisDescription
-from .body_description import BodyDescription
 from .case import Case, CaseListener, CaseResult
+from .description import Description
 from .extraction import (
     Extractor,
     JqExtractor,
@@ -11,10 +10,13 @@ from .extraction import (
 )
 from .matcher import Matcher, StaticMatcher, ValueMatcher, RecursiveMatcher
 from .predicate import Predicate, MatcherPredicate
-from .request import Request, Parameter, Parameters, ParameterValue
-from .response_description import ResponseDescription, ResponseVerification
+from .request import Request, Method
+from .request_body import RequestBody, UrlencodedRequestBody, JsonRequestBody
+from .response import ResponseDescription, ResponseVerification
+from .response_body import ResponseBodyDescription
 from .scenario import Scenario, ScenarioListener, ScenarioResult, ScenarioTask
 from .status import Status, Statused, StatusedList
+from .url_param import UrlParam, UrlParams, UrlParamValue
 from .verification import Verification
 
 __all__ = [
@@ -22,8 +24,7 @@ __all__ = [
     'Analysis',
     'analyze_json_str',
     'analyze_xml_str',
-    'AnalysisDescription',
-    'BodyDescription',
+    'Description',
     'Case',
     'CaseListener',
     'CaseResult',
@@ -39,11 +40,13 @@ __all__ = [
     'Predicate',
     'MatcherPredicate',
     'Request',
-    'Parameter',
-    'Parameters',
-    'ParameterValue',
+    'Method',
+    'RequestBody',
+    'UrlencodedRequestBody',
+    'JsonRequestBody',
     'ResponseDescription',
     'ResponseVerification',
+    'ResponseBodyDescription',
     'Scenario',
     'ScenarioTask',
     'ScenarioListener',
@@ -51,5 +54,8 @@ __all__ = [
     'Status',
     'Statused',
     'StatusedList',
+    'UrlParam',
+    'UrlParams',
+    'UrlParamValue',
     'Verification',
 ]
